@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# Copyright (c) 2004-2007 by Nicolas FRANÇOIS <nicolas.francois@centraliens.net>
+# Copyright © 2004-2007 Nicolas FRANÇOIS <nicolas.francois@centraliens.net>
 #
 # This file is part of po4a.
 #
@@ -56,7 +56,7 @@ L<po4a(7)|po4a.7>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2007 by Nicolas FRANÇOIS <nicolas.francois@centraliens.net>.
+Copyright © 2004-2007 Nicolas FRANÇOIS <nicolas.francois@centraliens.net>.
 
 This program is free software; you may redistribute it and/or modify it
 under the terms of GPL (see COPYING file).
@@ -334,7 +334,11 @@ sub translate_buffer_menuentry {
             $l = $menu_sep_width-1;
         }
         ($t, @e) = $self->translate_buffer($description, $no_wrap, @env);
-        $t =~ s/\n//sg;
+        # Replace newlines with space for proper wrapping
+        # See https://github.com/mquinson/po4a/issues/122
+        $t =~ s/\n/ /sg;
+        # Remove trailing spaces
+        $t =~ s/\s*$//;
         $t = Locale::Po4a::Po::wrap($t, $menu_width-$l-2);
         my $spaces = ' 'x($l+2);
         $t =~ s/\n/\n$spaces/sg;
