@@ -7,8 +7,8 @@
 # This code extracts plain text from tags and attributes from strict XHTML
 # documents.
 #
-# Copyright (c) 2005 by Yves Rütschlé <po4a@rutschle.net>
-# Copyright (c) 2007-2008 by Nicolas François <nicolas.francois@centraliens.net>
+# Copyright © 2005 Yves Rütschlé <po4a@rutschle.net>
+# Copyright © 2007-2008 Nicolas François <nicolas.francois@centraliens.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 ########################################################################
 
@@ -79,8 +80,8 @@ L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>, L<po4a(7)|po4a.7>
 
 =head1 COPYRIGHT AND LICENSE
 
- Copyright (c) 2004 by Yves Rütschlé <po4a@rutschle.net>
- Copyright (c) 2007-2008 by Nicolas François <nicolas.francois@centraliens.net>
+ Copyright © 2004 Yves Rütschlé <po4a@rutschle.net>
+ Copyright © 2007-2008 Nicolas François <nicolas.francois@centraliens.net>
 
 This program is free software; you may redistribute it and/or modify it
 under the terms of GPL (see the COPYING file).
@@ -220,6 +221,7 @@ sub initialize {
                 lang
                 title
                 ';
+        print wrap_mod("po4a::Xhtml", dgettext("po4a", "Call treat_options")) if $self->{options}{'debug'};
         $self->treat_options;
 
         if (    defined $self->{options}{'includessi'}
